lineage.nodes - Function for internal Blouch use Given a certain node, return the list of all parent nodes back to the root of the tree
lineage.nodes.Rdlineage.nodes - Function for internal Blouch use Given a certain node, return the list of all parent nodes back to the root of the tree